@@ -8,15 +8,15 @@ use AxKit;
 use AxKit::App::TABOO::Data::Comment;
 use AxKit::App::TABOO::Data::Plurals::Comments;
 use AxKit::App::TABOO::Data::Story;
-use Apache::AxKit::Plugin::BasicSession;
+use AxKit::App::TABOO;
+use Session;
 use Time::Piece ':override';
 use XML::LibXML;
-
-
+use Net::Akismet;
 
 use vars qw/$NS/;
 
-our $VERSION = '0.094';
+our $VERSION = '0.51';
 
 =head1 NAME
 
@@ -80,6 +80,11 @@ logged in and authenticated with an authorization level. If an
 authlevel is not found in the user's session object, it will throw an
 exceptions with an C<AUTH_REQUIRED> code.
 
+If TABOOAkismetKey is set (and spammers will make you want this really
+fast), it will check the Akismet anti-spam system if the user has an
+authlevel less than 2, and return a C<FORBIDDEN> if it is deemed to be
+spam.
+
 Finally, the Data object is instructed to save itself.
 
 If successful, it will return a C<store> element in the output
@@ -94,9 +99,10 @@ sub store : node({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Comment/Outpu
     foreach my $name ($cgi->param) {
       $args{$name} = $cgi->param($name);
     }
-    $args{'username'} = $Apache::AxKit::Plugin::BasicSession::session{credential_0};
+    my $session = AxKit::App::TABOO::session($r);
+    $args{'username'} = AxKit::App::TABOO::loggedin($session);
 
-    my $authlevel =  $Apache::AxKit::Plugin::BasicSession::session{authlevel};
+    my $authlevel = AxKit::App::TABOO::authlevel($session);
     AxKit::Debug(6, "Logged in as $args{'username'} at level $authlevel");
     unless (defined($authlevel)) {
 	throw Apache::AxKit::Exception::Retval(
@@ -127,6 +133,29 @@ sub store : node({http://www.kjetil.kjernsmo.net/software/TABOO/NS/Comment/Outpu
     }
     delete $args{'parentcpath'};
 
+    if ($r->dir_config('TABOOAkismetKey')) {
+      AxKit::Debug(9, "Using Akismet");
+      my $akismet = Net::Akismet->new(
+                        KEY => $r->dir_config('TABOOAkismetKey'),
+                        URL => $r->dir_config('TABOOAkismetURL'),
+                ) or throw Apache::AxKit::Exception::Error(-text => "Akismet key verification failed.");
+      my %akismetstuff = (USER_IP => $r->header_in('X-Forwarded-For'),
+			  COMMENT_CONTENT => $args{'content'},
+			  REFERRER => $r->header_in('Referer'),
+			  COMMENT_TYPE => 'comment',
+			 );
+      if ($authlevel >= 2) { # Presumed ham
+	$akismet->ham(%akismetstuff);
+      } else {
+	AxKit::Debug(10, "Akismet check on: ".join("    ",values(%akismetstuff)));
+	if ($akismet->check(%akismetstuff) eq 'true') {
+	  throw Apache::AxKit::Exception::Retval(
+						 return_code => FORBIDDEN,
+						 -text => "Akismet check says that your comment is spam. Please contact webmaster if you received this message in error.");
+	}
+      }
+    }
+
     my $comment = AxKit::App::TABOO::Data::Comment->new();
     $comment->populate(\%args);
     $comment->save();
@@ -156,7 +185,7 @@ sub this_comment : struct {
     foreach my $name ($cgi->param) {
       $args{$name} = $cgi->param($name);
     }
-    $args{'username'} = $Apache::AxKit::Plugin::BasicSession::session{credential_0};
+    $args{'username'} = AxKit::App::TABOO::loggedin(AxKit::App::TABOO::session($r));
     my $timestamp = localtime;
     unless ($args{'timestamp'}) {
 	$args{'timestamp'} = $timestamp->datetime;
